clc;
close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% User Defined Parameters %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sizeRatio = 0.125;	% The range of the size ratio: (0, 0.9]
F_ad = 50e-9;       % Adhesion force, unit: N
miu = 0.111;        % Friction coefficient of the wall
vis = 1.82e-5;      % Dynamic viscosity
kvis = 1.51e-5;     % Kinematic viscosity

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
syms x Re_cri

x = sizeRatio;      % x is the size ratio Da/Dp
alpha = asin(x);    % The contact angle 

% Drag coefficient of Eq.9
c_D=(1/Re_cri)*((38.50213+3.96891*x-18.7913*x^2)+(6.50022+0.04449*x-4.25673*x^2)*Re_cri^(0.71745+0.02358*x-0.04133*x^2));

% Lift coefficient of Eq.9
c_L=(3.6005-1.27124*x^3.45483)/((Re_cri^(2.10292+2.19827*x^4.4278)+0.10478+0.20919*x^5.50335))^(0.20617-0.10562*x^2.69316);

% Torque coefficient of Eq.9
c_M=(0.34488-0.02826*x+0.13448*x^2+0.02015*x^3)+(0.0575+0.00924*x-0.06593*x^2+0.07684*x^3)*Re_cri^(0.29126-0.18496*x+0.90734*x^2-0.51498*x^3);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%% Re_cri_lift %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Eqs.13-14 of the lift
eqnLift=Re_cri^2*((1.2074*pi/8)*kvis^2)*c_L==F_ad;

% Solve the critical Re_p of the lifting detachment
Re_cri_lift = vpasolve(eqnLift,Re_cri);
disp(['The critical particle Reynolds number for lifting detachment is: ']);
disp(Re_cri_lift);

% Solve the dimensionless adhesion force for the critical Re_p of the lifting detachment
% The dimensionless adhesion force is F_ad_new throughout the code
F_ad_new = 0.5*F_ad/(vis*Re_cri_lift*kvis);     
disp(['The dimensionless adhesion force for the critical Re_p of the lifting detachment is: ']);
disp(F_ad_new);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%% Re_cri_slide %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Eqs.13-14 of the slide
eqnSlide=Re_cri^2*c_D*((1.2074*pi/8)*kvis^2)*(cos(alpha)-miu*sin(alpha))+Re_cri^2*((1.2074*pi/8)*kvis^2)*c_L*(sin(alpha)+miu*cos(alpha))==(F_ad)*(sin(alpha) + miu*cos(alpha));

% Solve the critical Re_p of the sliding detachment
Re_cri_slide = vpasolve(eqnSlide,Re_cri);
disp(['The critical particle Reynolds number for sliding detachment is: ']);
disp(Re_cri_slide);

% Solve the dimensionless adhesion force for the critical Re_p of the sliding detachment
F_ad_new = 0.5*F_ad/(vis*Re_cri_slide*kvis);
disp(['The dimensionless adhesion force for the critical Re_p of the sliding detachment is: ']);
disp(F_ad_new);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%% Re_cri_roll %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Eqs.13-14 of the roll
eqnRoll=Re_cri^2*c_D*((1.2074*pi/8)*kvis^2)*(cos(alpha)+c_M)+Re_cri^2*((1.2074*pi/8)*kvis^2)*c_L*sin(alpha)==(F_ad)*sin(alpha);

% Solve the critical Re_p of the rolling detachment
Re_cri_roll = vpasolve(eqnRoll,Re_cri);
disp(['The critical particle Reynolds number for rolling detachment is: ']);
disp(Re_cri_roll);

% Solve the dimensionless adhesion force for the critical Re_p of the rolling detachment
F_ad_new = 0.5*F_ad/(vis*Re_cri_roll*kvis);
disp(['The dimensionless adhesion force for the critical Re_p of the rolling detachment is: ']);
disp(F_ad_new);

